``pyramid_amon`` README
==========================

Pyramid Amon is an add-on for the Pyramid Web Framework which allows
developers to integrate their application with Amon application and system
monitoring toolkit.

More information about Amon at `http://amon.cx/
<http://amon.cx/>`_.

See the `documentation at Pylons Project Docs
<http://docs.pylonsproject.org/projects/pyramid_amon/en/latest/>`_.
